
from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from sentinel.types.v1 import status_pb2 as _status_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class MsgCreateRequest(_message.Message):
    __slots__ = ['duration', 'frm', 'gigabytes', 'prices']
    DURATION_FIELD_NUMBER: _ClassVar[int]
    FRM_FIELD_NUMBER: _ClassVar[int]
    GIGABYTES_FIELD_NUMBER: _ClassVar[int]
    PRICES_FIELD_NUMBER: _ClassVar[int]
    duration: _duration_pb2.Duration
    frm: str
    gigabytes: int
    prices: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]

    def __init__(self, frm: _Optional[str]=..., duration: _Optional[_Union[(_duration_pb2.Duration, _Mapping)]]=..., gigabytes: _Optional[int]=..., prices: _Optional[_Iterable[_Union[(_coin_pb2.Coin, _Mapping)]]]=...) -> None:
        ...

class MsgCreateResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class MsgLinkNodeRequest(_message.Message):
    __slots__ = ['frm', 'id', 'node_address']
    FRM_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NODE_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    frm: str
    id: int
    node_address: str

    def __init__(self, frm: _Optional[str]=..., id: _Optional[int]=..., node_address: _Optional[str]=...) -> None:
        ...

class MsgLinkNodeResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class MsgSubscribeRequest(_message.Message):
    __slots__ = ['denom', 'frm', 'id']
    DENOM_FIELD_NUMBER: _ClassVar[int]
    FRM_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    denom: str
    frm: str
    id: int

    def __init__(self, frm: _Optional[str]=..., id: _Optional[int]=..., denom: _Optional[str]=...) -> None:
        ...

class MsgSubscribeResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class MsgUnlinkNodeRequest(_message.Message):
    __slots__ = ['frm', 'id', 'node_address']
    FRM_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NODE_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    frm: str
    id: int
    node_address: str

    def __init__(self, frm: _Optional[str]=..., id: _Optional[int]=..., node_address: _Optional[str]=...) -> None:
        ...

class MsgUnlinkNodeResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class MsgUpdateStatusRequest(_message.Message):
    __slots__ = ['frm', 'id', 'status']
    FRM_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    frm: str
    id: int
    status: _status_pb2.Status

    def __init__(self, frm: _Optional[str]=..., id: _Optional[int]=..., status: _Optional[_Union[(_status_pb2.Status, str)]]=...) -> None:
        ...

class MsgUpdateStatusResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from ....cosmos.bank.v1beta1 import bank_pb2 as cosmos_dot_bank_dot_v1beta1_dot_bank__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!cosmos/bank/v1beta1/genesis.proto\x12\x13cosmos.bank.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1ecosmos/base/v1beta1/coin.proto\x1a\x1ecosmos/bank/v1beta1/bank.proto"\xaa\x02\n\x0cGenesisState\x121\n\x06params\x18\x01 \x01(\x0b2\x1b.cosmos.bank.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\x124\n\x08balances\x18\x02 \x03(\x0b2\x1c.cosmos.bank.v1beta1.BalanceB\x04\xc8\xde\x1f\x00\x12[\n\x06supply\x18\x03 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinB0\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xc8\xde\x1f\x00\x12T\n\x0edenom_metadata\x18\x04 \x03(\x0b2\x1d.cosmos.bank.v1beta1.MetadataB\x1d\xf2\xde\x1f\x15yaml:"denom_metadata"\xc8\xde\x1f\x00"\x80\x01\n\x07Balance\x12\x0f\n\x07address\x18\x01 \x01(\t\x12Z\n\x05coins\x18\x02 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinB0\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00B+Z)github.com/cosmos/cosmos-sdk/x/bank/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.bank.v1beta1.genesis_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/x/bank/types'
    _GENESISSTATE.fields_by_name['params']._options = None
    _GENESISSTATE.fields_by_name['params']._serialized_options = b'\xc8\xde\x1f\x00'
    _GENESISSTATE.fields_by_name['balances']._options = None
    _GENESISSTATE.fields_by_name['balances']._serialized_options = b'\xc8\xde\x1f\x00'
    _GENESISSTATE.fields_by_name['supply']._options = None
    _GENESISSTATE.fields_by_name['supply']._serialized_options = b'\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xc8\xde\x1f\x00'
    _GENESISSTATE.fields_by_name['denom_metadata']._options = None
    _GENESISSTATE.fields_by_name['denom_metadata']._serialized_options = b'\xf2\xde\x1f\x15yaml:"denom_metadata"\xc8\xde\x1f\x00'
    _BALANCE.fields_by_name['coins']._options = None
    _BALANCE.fields_by_name['coins']._serialized_options = b'\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xc8\xde\x1f\x00'
    _BALANCE._options = None
    _BALANCE._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _GENESISSTATE._serialized_start = 145
    _GENESISSTATE._serialized_end = 443
    _BALANCE._serialized_start = 446
    _BALANCE._serialized_end = 574




from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional
DESCRIPTOR: _descriptor.FileDescriptor

class Allocation(_message.Message):
    __slots__ = ['address', 'granted_bytes', 'id', 'utilised_bytes']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    GRANTED_BYTES_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    UTILISED_BYTES_FIELD_NUMBER: _ClassVar[int]
    address: str
    granted_bytes: str
    id: int
    utilised_bytes: str

    def __init__(self, id: _Optional[int]=..., address: _Optional[str]=..., granted_bytes: _Optional[str]=..., utilised_bytes: _Optional[str]=...) -> None:
        ...




from cosmos_proto import cosmos_pb2 as _cosmos_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos.auth.v1beta1 import auth_pb2 as _auth_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class InterchainAccount(_message.Message):
    __slots__ = ['account_owner', 'base_account']
    ACCOUNT_OWNER_FIELD_NUMBER: _ClassVar[int]
    BASE_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    account_owner: str
    base_account: _auth_pb2.BaseAccount

    def __init__(self, base_account: _Optional[_Union[(_auth_pb2.BaseAccount, _Mapping)]]=..., account_owner: _Optional[str]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n sentinel/mint/v1/inflation.proto\x12\x10sentinel.mint.v1\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\xc9\x02\n\tInflation\x12I\n\x03max\x18\x01 \x01(\tB<\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xf2\xde\x1f\nyaml:"max"\xc8\xde\x1f\x00\x12I\n\x03min\x18\x02 \x01(\tB<\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xf2\xde\x1f\nyaml:"min"\xc8\xde\x1f\x00\x12Y\n\x0brate_change\x18\x03 \x01(\tBD\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xf2\xde\x1f\x12yaml:"rate_change"\xc8\xde\x1f\x00\x12K\n\ttimestamp\x18\x04 \x01(\x0b2\x1a.google.protobuf.TimestampB\x1c\xf2\xde\x1f\x10yaml:"timestamp"\xc8\xde\x1f\x00\x90\xdf\x1f\x01B7Z-github.com/sentinel-official/hub/x/mint/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.mint.v1.inflation_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/mint/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _INFLATION.fields_by_name['max']._options = None
    _INFLATION.fields_by_name['max']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xf2\xde\x1f\nyaml:"max"\xc8\xde\x1f\x00'
    _INFLATION.fields_by_name['min']._options = None
    _INFLATION.fields_by_name['min']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xf2\xde\x1f\nyaml:"min"\xc8\xde\x1f\x00'
    _INFLATION.fields_by_name['rate_change']._options = None
    _INFLATION.fields_by_name['rate_change']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xf2\xde\x1f\x12yaml:"rate_change"\xc8\xde\x1f\x00'
    _INFLATION.fields_by_name['timestamp']._options = None
    _INFLATION.fields_by_name['timestamp']._serialized_options = b'\xf2\xde\x1f\x10yaml:"timestamp"\xc8\xde\x1f\x00\x90\xdf\x1f\x01'
    _INFLATION._serialized_start = 110
    _INFLATION._serialized_end = 439




from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional
DESCRIPTOR: _descriptor.FileDescriptor

class Minter(_message.Message):
    __slots__ = ['annual_provisions', 'inflation']
    ANNUAL_PROVISIONS_FIELD_NUMBER: _ClassVar[int]
    INFLATION_FIELD_NUMBER: _ClassVar[int]
    annual_provisions: str
    inflation: str

    def __init__(self, inflation: _Optional[str]=..., annual_provisions: _Optional[str]=...) -> None:
        ...

class Params(_message.Message):
    __slots__ = ['blocks_per_year', 'goal_bonded', 'inflation_max', 'inflation_min', 'inflation_rate_change', 'mint_denom']
    BLOCKS_PER_YEAR_FIELD_NUMBER: _ClassVar[int]
    GOAL_BONDED_FIELD_NUMBER: _ClassVar[int]
    INFLATION_MAX_FIELD_NUMBER: _ClassVar[int]
    INFLATION_MIN_FIELD_NUMBER: _ClassVar[int]
    INFLATION_RATE_CHANGE_FIELD_NUMBER: _ClassVar[int]
    MINT_DENOM_FIELD_NUMBER: _ClassVar[int]
    blocks_per_year: int
    goal_bonded: str
    inflation_max: str
    inflation_min: str
    inflation_rate_change: str
    mint_denom: str

    def __init__(self, mint_denom: _Optional[str]=..., inflation_rate_change: _Optional[str]=..., inflation_max: _Optional[str]=..., inflation_min: _Optional[str]=..., goal_bonded: _Optional[str]=..., blocks_per_year: _Optional[int]=...) -> None:
        ...




from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional
DESCRIPTOR: _descriptor.FileDescriptor

class EventSwap(_message.Message):
    __slots__ = ['receiver', 'tx_hash']
    RECEIVER_FIELD_NUMBER: _ClassVar[int]
    TX_HASH_FIELD_NUMBER: _ClassVar[int]
    receiver: str
    tx_hash: bytes

    def __init__(self, tx_hash: _Optional[bytes]=..., receiver: _Optional[str]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from ....sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2
from ....sentinel.plan.v2 import plan_pb2 as sentinel_dot_plan_dot_v2_dot_plan__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1esentinel/plan/v2/querier.proto\x12\x10sentinel.plan.v2\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1esentinel/types/v1/status.proto\x1a\x1bsentinel/plan/v2/plan.proto"z\n\x11QueryPlansRequest\x12)\n\x06status\x18\x01 \x01(\x0e2\x19.sentinel.types.v1.Status\x12:\n\npagination\x18\x02 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"\x96\x01\n\x1cQueryPlansForProviderRequest\x12\x0f\n\x07address\x18\x01 \x01(\t\x12)\n\x06status\x18\x02 \x01(\x0e2\x19.sentinel.types.v1.Status\x12:\n\npagination\x18\x03 \x01(\x0b2&.cosmos.base.query.v1beta1.PageRequest"\x1e\n\x10QueryPlanRequest\x12\n\n\x02id\x18\x01 \x01(\x04"~\n\x12QueryPlansResponse\x12+\n\x05plans\x18\x01 \x03(\x0b2\x16.sentinel.plan.v2.PlanB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"\x89\x01\n\x1dQueryPlansForProviderResponse\x12+\n\x05plans\x18\x01 \x03(\x0b2\x16.sentinel.plan.v2.PlanB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b2\'.cosmos.base.query.v1beta1.PageResponse"?\n\x11QueryPlanResponse\x12*\n\x04plan\x18\x01 \x01(\x0b2\x16.sentinel.plan.v2.PlanB\x04\xc8\xde\x1f\x002\x9c\x03\n\x0cQueryService\x12p\n\nQueryPlans\x12#.sentinel.plan.v2.QueryPlansRequest\x1a$.sentinel.plan.v2.QueryPlansResponse"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/sentinel/plans\x12\xa5\x01\n\x15QueryPlansForProvider\x12..sentinel.plan.v2.QueryPlansForProviderRequest\x1a/.sentinel.plan.v2.QueryPlansForProviderResponse"+\x82\xd3\xe4\x93\x02%\x12#/sentinel/providers/{address}/plans\x12r\n\tQueryPlan\x12".sentinel.plan.v2.QueryPlanRequest\x1a#.sentinel.plan.v2.QueryPlanResponse"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/sentinel/plans/{id}B7Z-github.com/sentinel-official/hub/x/plan/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.plan.v2.querier_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/plan/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _QUERYPLANSRESPONSE.fields_by_name['plans']._options = None
    _QUERYPLANSRESPONSE.fields_by_name['plans']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYPLANSFORPROVIDERRESPONSE.fields_by_name['plans']._options = None
    _QUERYPLANSFORPROVIDERRESPONSE.fields_by_name['plans']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYPLANRESPONSE.fields_by_name['plan']._options = None
    _QUERYPLANRESPONSE.fields_by_name['plan']._serialized_options = b'\xc8\xde\x1f\x00'
    _QUERYSERVICE.methods_by_name['QueryPlans']._options = None
    _QUERYSERVICE.methods_by_name['QueryPlans']._serialized_options = b'\x82\xd3\xe4\x93\x02\x11\x12\x0f/sentinel/plans'
    _QUERYSERVICE.methods_by_name['QueryPlansForProvider']._options = None
    _QUERYSERVICE.methods_by_name['QueryPlansForProvider']._serialized_options = b'\x82\xd3\xe4\x93\x02%\x12#/sentinel/providers/{address}/plans'
    _QUERYSERVICE.methods_by_name['QueryPlan']._options = None
    _QUERYSERVICE.methods_by_name['QueryPlan']._serialized_options = b'\x82\xd3\xe4\x93\x02\x16\x12\x14/sentinel/plans/{id}'
    _QUERYPLANSREQUEST._serialized_start = 209
    _QUERYPLANSREQUEST._serialized_end = 331
    _QUERYPLANSFORPROVIDERREQUEST._serialized_start = 334
    _QUERYPLANSFORPROVIDERREQUEST._serialized_end = 484
    _QUERYPLANREQUEST._serialized_start = 486
    _QUERYPLANREQUEST._serialized_end = 516
    _QUERYPLANSRESPONSE._serialized_start = 518
    _QUERYPLANSRESPONSE._serialized_end = 644
    _QUERYPLANSFORPROVIDERRESPONSE._serialized_start = 647
    _QUERYPLANSFORPROVIDERRESPONSE._serialized_end = 784
    _QUERYPLANRESPONSE._serialized_start = 786
    _QUERYPLANRESPONSE._serialized_end = 849
    _QUERYSERVICE._serialized_start = 852
    _QUERYSERVICE._serialized_end = 1264




from cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.api import annotations_pb2 as _annotations_pb2
from cosmos.gov.v1beta1 import gov_pb2 as _gov_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class QueryDepositRequest(_message.Message):
    __slots__ = ['depositor', 'proposal_id']
    DEPOSITOR_FIELD_NUMBER: _ClassVar[int]
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    depositor: str
    proposal_id: int

    def __init__(self, proposal_id: _Optional[int]=..., depositor: _Optional[str]=...) -> None:
        ...

class QueryDepositResponse(_message.Message):
    __slots__ = ['deposit']
    DEPOSIT_FIELD_NUMBER: _ClassVar[int]
    deposit: _gov_pb2.Deposit

    def __init__(self, deposit: _Optional[_Union[(_gov_pb2.Deposit, _Mapping)]]=...) -> None:
        ...

class QueryDepositsRequest(_message.Message):
    __slots__ = ['pagination', 'proposal_id']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    proposal_id: int

    def __init__(self, proposal_id: _Optional[int]=..., pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QueryDepositsResponse(_message.Message):
    __slots__ = ['deposits', 'pagination']
    DEPOSITS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    deposits: _containers.RepeatedCompositeFieldContainer[_gov_pb2.Deposit]
    pagination: _pagination_pb2.PageResponse

    def __init__(self, deposits: _Optional[_Iterable[_Union[(_gov_pb2.Deposit, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...

class QueryParamsRequest(_message.Message):
    __slots__ = ['params_type']
    PARAMS_TYPE_FIELD_NUMBER: _ClassVar[int]
    params_type: str

    def __init__(self, params_type: _Optional[str]=...) -> None:
        ...

class QueryParamsResponse(_message.Message):
    __slots__ = ['deposit_params', 'tally_params', 'voting_params']
    DEPOSIT_PARAMS_FIELD_NUMBER: _ClassVar[int]
    TALLY_PARAMS_FIELD_NUMBER: _ClassVar[int]
    VOTING_PARAMS_FIELD_NUMBER: _ClassVar[int]
    deposit_params: _gov_pb2.DepositParams
    tally_params: _gov_pb2.TallyParams
    voting_params: _gov_pb2.VotingParams

    def __init__(self, voting_params: _Optional[_Union[(_gov_pb2.VotingParams, _Mapping)]]=..., deposit_params: _Optional[_Union[(_gov_pb2.DepositParams, _Mapping)]]=..., tally_params: _Optional[_Union[(_gov_pb2.TallyParams, _Mapping)]]=...) -> None:
        ...

class QueryProposalRequest(_message.Message):
    __slots__ = ['proposal_id']
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    proposal_id: int

    def __init__(self, proposal_id: _Optional[int]=...) -> None:
        ...

class QueryProposalResponse(_message.Message):
    __slots__ = ['proposal']
    PROPOSAL_FIELD_NUMBER: _ClassVar[int]
    proposal: _gov_pb2.Proposal

    def __init__(self, proposal: _Optional[_Union[(_gov_pb2.Proposal, _Mapping)]]=...) -> None:
        ...

class QueryProposalsRequest(_message.Message):
    __slots__ = ['depositor', 'pagination', 'proposal_status', 'voter']
    DEPOSITOR_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    PROPOSAL_STATUS_FIELD_NUMBER: _ClassVar[int]
    VOTER_FIELD_NUMBER: _ClassVar[int]
    depositor: str
    pagination: _pagination_pb2.PageRequest
    proposal_status: _gov_pb2.ProposalStatus
    voter: str

    def __init__(self, proposal_status: _Optional[_Union[(_gov_pb2.ProposalStatus, str)]]=..., voter: _Optional[str]=..., depositor: _Optional[str]=..., pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QueryProposalsResponse(_message.Message):
    __slots__ = ['pagination', 'proposals']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    PROPOSALS_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    proposals: _containers.RepeatedCompositeFieldContainer[_gov_pb2.Proposal]

    def __init__(self, proposals: _Optional[_Iterable[_Union[(_gov_pb2.Proposal, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...

class QueryTallyResultRequest(_message.Message):
    __slots__ = ['proposal_id']
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    proposal_id: int

    def __init__(self, proposal_id: _Optional[int]=...) -> None:
        ...

class QueryTallyResultResponse(_message.Message):
    __slots__ = ['tally']
    TALLY_FIELD_NUMBER: _ClassVar[int]
    tally: _gov_pb2.TallyResult

    def __init__(self, tally: _Optional[_Union[(_gov_pb2.TallyResult, _Mapping)]]=...) -> None:
        ...

class QueryVoteRequest(_message.Message):
    __slots__ = ['proposal_id', 'voter']
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    VOTER_FIELD_NUMBER: _ClassVar[int]
    proposal_id: int
    voter: str

    def __init__(self, proposal_id: _Optional[int]=..., voter: _Optional[str]=...) -> None:
        ...

class QueryVoteResponse(_message.Message):
    __slots__ = ['vote']
    VOTE_FIELD_NUMBER: _ClassVar[int]
    vote: _gov_pb2.Vote

    def __init__(self, vote: _Optional[_Union[(_gov_pb2.Vote, _Mapping)]]=...) -> None:
        ...

class QueryVotesRequest(_message.Message):
    __slots__ = ['pagination', 'proposal_id']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    proposal_id: int

    def __init__(self, proposal_id: _Optional[int]=..., pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QueryVotesResponse(_message.Message):
    __slots__ = ['pagination', 'votes']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    VOTES_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    votes: _containers.RepeatedCompositeFieldContainer[_gov_pb2.Vote]

    def __init__(self, votes: _Optional[_Iterable[_Union[(_gov_pb2.Vote, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...




from gogoproto import gogo_pb2 as _gogo_pb2
from sentinel.session.v2 import proof_pb2 as _proof_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class MsgEndRequest(_message.Message):
    __slots__ = ['frm', 'id', 'rating']
    FRM_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    RATING_FIELD_NUMBER: _ClassVar[int]
    frm: str
    id: int
    rating: int

    def __init__(self, frm: _Optional[str]=..., id: _Optional[int]=..., rating: _Optional[int]=...) -> None:
        ...

class MsgEndResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class MsgStartRequest(_message.Message):
    __slots__ = ['address', 'frm', 'id']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    FRM_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    address: str
    frm: str
    id: int

    def __init__(self, frm: _Optional[str]=..., id: _Optional[int]=..., address: _Optional[str]=...) -> None:
        ...

class MsgStartResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class MsgUpdateDetailsRequest(_message.Message):
    __slots__ = ['frm', 'proof', 'signature']
    FRM_FIELD_NUMBER: _ClassVar[int]
    PROOF_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    frm: str
    proof: _proof_pb2.Proof
    signature: bytes

    def __init__(self, frm: _Optional[str]=..., proof: _Optional[_Union[(_proof_pb2.Proof, _Mapping)]]=..., signature: _Optional[bytes]=...) -> None:
        ...

class MsgUpdateDetailsResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...
